# ecst 

🚧 WIP 🚧

Create local tunnels and sessions to AWS ECS services running in a VPC.

## Prerequesites

* macOS (sorry)
* [AWS CLI Session Manager plugin](https://docs.aws.amazon.com/systems-manager/latest/userguide/session-manager-working-with-install-plugin.html)

## Usage

```
usage: ecst [-h] [--local-port LOCAL_PORT] [--remote-port REMOTE_PORT]
                  [--region REGION] [--aws-profile AWS_PROFILE]
                  cluster service
```
